% Constructor of the finite elements block class.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
% mater =material, 
% gcells = cell array of geometry cells,
% integration_rule= integration rule object
% Rm= transformation matrix, in columns are the basis vectors expressed in
%   the global Cartesian basis.
%
function retobj = feblock (varargin)
    class_name='feblock';
    parent=classbase;
    if (nargin == 0)
        self.mater = [];
        self.gcells = [];
        self.integration_rule = [];
        self.matstates = [];
        self.Rm=[];
        retobj = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            self.mater = options.mater;
            self.gcells = options.gcells;
            if (length(self.gcells) < 1)
                error('Need at least one gcell!');
            end
            for i=1:length(self.gcells)
                if (~isa(self.gcells(i),class(self.gcells(1))))
                    error ('All gcells must be of the same class!');
                end
            end
            self.integration_rule = options.integration_rule;
            if ~isempty(self.integration_rule)
                npts_per_gcell = get(self.integration_rule,'npts_per_gcell');
                self.matstates = cell(get(self.gcells(1),'nfens')*length(self.gcells),npts_per_gcell);
                for i=1:length(self.gcells)
                    for j=1:npts_per_gcell;
                        self.matstates{i,j} = newmatstate(self.mater);
                    end
                end
            else
                self.matstates = [];
            end
            Rm=[];
            if isfield(options,'Rm')
                Rm= options.Rm;
                if norm(inv(Rm)-Rm')>1e-9
                    error('Non-orthogonal local basis matrix!');
                end
            end
            self.Rm=Rm;
            retobj = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end

