% Compute the element load vectors corresponding to nonzero essential boundary
% conditions (settlement of the supports).
% Return an array of them so they may be assembled.
%    Call as
% evs = nz_ebc_loads(feb, geom, u)
%     geom=geometry field
%     u=displacement field
%
function evs = nz_ebc_loads(self, geom, u)
gcells = get(self.feblock,'gcells');
ngcells = length(gcells);
nfens = get(gcells(1),'nfens');
dim = get(geom,'dim');
% Pre-allocate the element matrices
evs(1:ngcells) = deal(elevec);
% Integration rule
integration_rule = get(self.feblock, 'integration_rule');
pc = get(integration_rule, 'param_coords');
w  = get(integration_rule, 'weights');
npts_per_gcell = get(integration_rule, 'npts');
% Material
mat = get(self.feblock, 'mater');
matstates = get(self.feblock, 'matstates');
% Now loop over all gcells in the block
for i=1:ngcells
    conn = get(gcells(i), 'conn'); % connectivity
    pu = gather(u, conn, 'prescribed_values'); % prescribed values of displacement
    if norm (pu) ~= 0
        x = gather(geom, conn, 'values', 'noreshape'); % coordinates of nodes
        Ke = zeros(dim*nfens); % element stiffness matrix
        % Loop over all integration points
        for j=1:npts_per_gcell
            Nder = Ndermat_param (gcells(i), pc(j,:));
            ts=x'*Nder; % tangent vector to the centroid curve
            T=local_basis(self,ts); % calculate the local Cartesian basis
            xl=x*T(:,1);
            [Nspatialder,detJ] = Ndermat_spatial (gcells(i), Nder, xl);
            B = Blmat1(gcells(i), Nspatialder, T);
            D = tangent_moduli (mat, struct ('ms',matstates{i,j}));
            Ke = Ke + B'*D*B * detJ * area(gcells(i), pc(j,:)) * w(j);
        end
        evs(i) = set(evs(i), 'vec', -Ke*pu);
        evs(i) = set(evs(i), 'eqnums', gather(u, conn, 'eqnums'));
    end
end
return;

